Julia Fractal
*************

.. figure:: images/julia_fractal.png
	:scale: 50 %
	:alt: julia_fractal
	:align: center
	:figclass: align-center

	Julia Fractal

.. literalinclude:: ../../examples/GLWindow/julia_fractal.py
	:linenos:
